/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { IGitManager } from "@fluidframework/server-services-client";
import * as core from "@fluidframework/server-services-core";
export declare class Tenant implements core.ITenant {
    private readonly config;
    private readonly manager;
    get id(): string;
    get gitManager(): IGitManager;
    get storage(): core.ITenantStorage;
    get orderer(): core.ITenantOrderer;
    constructor(config: core.ITenantConfig, manager: IGitManager);
}
/**
 * Manages a collection of tenants
 */
export declare class TenantManager implements core.ITenantManager, core.ITenantConfigManager {
    private readonly endpoint;
    private readonly internalHistorianUrl;
    constructor(endpoint: string, internalHistorianUrl: string);
    createTenant(tenantId?: string): Promise<core.ITenantConfig & {
        key: string;
    }>;
    getTenant(tenantId: string, documentId: string, includeDisabledTenant?: boolean): Promise<core.ITenant>;
    getTenantGitManager(tenantId: string, documentId: string, storageName?: string, includeDisabledTenant?: boolean, isEphemeralContainer?: boolean): Promise<IGitManager>;
    verifyToken(tenantId: string, token: string): Promise<void>;
    getKey(tenantId: string, includeDisabledTenant?: boolean): Promise<string>;
    getTenantStorageName(tenantId: string, includeDisabledTenant?: boolean): Promise<string>;
    private getTenantConfig;
}
//# sourceMappingURL=tenant.d.ts.map